The Long-Term Real Rate Average is the unweighted average of bid real yields on all outstanding TIPS with remaining maturities of more than 10 years and is intended as a proxy for long-term real rates.
Value
A data.table::data.table() containing the rates or NULL when no entries were found.
The table carries an updated_at attribute with the feed's last update time as a POSIXct,
accessible via attr(x, "updated_at").
See also
Other interest rate:
tr_bill_rate(),
tr_long_term_rate(),
tr_real_yield_curve(),
tr_yield_curve()