Learn R Programming

treasury (version 0.4.0)

tr_bill_rate: Daily treasury bill rates

Description

These rates are the daily secondary market quotations on the most recently auctioned Treasury Bills for each maturity tranche (4-week, 8-week, 13-week, 17-week, 26-week, and 52-week) for which Treasury currently issues new bills.

Usage

tr_bill_rate(date = NULL)

tr_bill_rates(date = NULL)

Value

A data.table::data.table() containing the rates or NULL when no entries were found.

Arguments

date

(NULL | character(1) | numeric(1))
Date in format yyyy or yyyymm. If NULL, all data is returned. Default NULL.

Deprecated functions

tr_bill_rates() has been deprecated and will be removed in a future version. Please use tr_bill_rate() instead.

Details

Market quotations are obtained at approximately 3:30 PM each business day by the Federal Reserve Bank of New York. The Bank Discount rate is the rate at which a bill is quoted in the secondary market and is based on the par value, amount of the discount and a 360-day year. The Coupon Equivalent, also called the Bond Equivalent, or the Investment Yield, is the bill's yield based on the purchase price, discount, and a 365- or 366-day year. The Coupon Equivalent can be used to compare the yield on a discount bill to the yield on a nominal coupon security that pays semiannual interest with the same maturity date.

See Also

Other interest rate: tr_long_term_rate(), tr_real_long_term(), tr_real_yield_curve(), tr_yield_curve()

Examples

Run this code
# \donttest{
# get data for a single month
tr_bill_rate("202201")
# or for the entire year
tr_bill_rate(2022)
# }

Run the code above in your browser using DataLab