tr_cache_dir() returns the path where cached API responses are stored.
tr_cache_clear() clears all cached responses.
Value
tr_cache_dir() returns a string with the path to the cache directory.
tr_cache_clear() is called for its side effect of clearing the cached
responses and returns NULL invisibly.