Learn R Programming

treasury (version 0.4.0)

tr_yield_curve: Daily treasury par yield curve rates

Description

This par yield curve, which relates the par yield on a security to its time to maturity, is based on the closing market bid prices on the most recently auctioned Treasury securities in the over-the-counter market. The par yields are derived from input market prices, which are indicative quotations obtained by the Federal Reserve Bank of New York at approximately 3:30 PM each business day.

Usage

tr_yield_curve(date = NULL)

Value

A data.table::data.table() containing the rates or NULL when no entries were found.

Arguments

date

(NULL | character(1) | numeric(1))
Date in format yyyy or yyyymm. If NULL, all data is returned. Default NULL.

See Also

Other interest rate: tr_bill_rate(), tr_long_term_rate(), tr_real_long_term(), tr_real_yield_curve()

Examples

Run this code
# \donttest{
# get data for a single month
tr_yield_curve("202201")
# or for the entire year
tr_yield_curve(2022)
# }

Run the code above in your browser using DataLab